import sys
import asyncio
import logging
from threading import Thread

logger = logging.getLogger(__name__)


class Coro(Thread):
    def __init__(self):
        super().__init__(name='coroThread', daemon=False)
        self.loop = asyncio.new_event_loop()
        self.tasks = {}

    def run(self) -> None:
        try:
            asyncio.set_event_loop(self.loop)
        except:
            logger.error('协程启动失败')
            sys.exit()
        try:
            self.loop.run_forever()
        finally:
            self.loop.run_until_complete(self.loop.shutdown_asyncgens())
            self.loop.close()

    def add_task(self, coro, name=None):
        task = self.loop.create_task(coro, name=name)
        self.loop._csock.send(b'\0')
        name = task.get_name()
        self.tasks[name] = task
        return name

    def stop_task(self, name):
        self.tasks[name].cancel()

    def get_result(self, name):
        try:
            res = self.tasks[name].result()
            del self.tasks[name]
        except Exception as e:
            res = str(e)
        return res

    def is_done(self, name):
        return self.tasks[name].done()



# coding=utf-8

try:
    from setuptools import setup, find_packages
    # res = find_packages()
except ImportError:
    from distutils.core import setup

setup(
    name='yuan-tool',  # 打包后的包文件名
    version='2.28',  # 版本号
    keywords="pip",  # 关键字
    description='some common components for personal use',  # 说明
    long_description="some common components for personal use",  # 详细说明
    # license="MIT Licence",  # 许可
    url='',  # 一般是GitHub项目路径
    author='narukami_yume',
    author_email='100961220@qq.com',
    # packages=find_packages(),     #这个参数是导入目录下的所有__init__.py包
    include_package_data=True,
    platforms="any",
    python_requires='>=3.6',
    install_requires=['requests>=2.25',
                      'lxml>=4.5.2',
                      'IPy>=1.01',
                      'PyYAML>=5.4.1',
                      'paramiko',
                      'colorama',
                      'pycryptodome',
                      'ruamel.yaml',
                      'redis',
                      'pymongo',
                      'pymysql',
                      'kafka-python',
                      'elasticsearch',
                      'DBUtils',
                      'pyDes',
                      'Crypto',
                      'dnspython',
                      'tld',
                      'psutil',
                      'cchardet',
                      'pika'
                      ],  # 引用到的第三方库
    # py_modules=['pip-test.DoRequest', 'pip-test.GetParams', 'pip-test.ServiceRequest',
    #             'pip-test.ts.constants', 'pip-test.ac.Agent2C',
    #             'pip-test.ts.ttypes', 'pip-test.ac.constants',
    #             'pip-test.__init__'],  # 你要打包的文件，这里用下面这个参数代替
    packages=['yuantool', 'yuantool.database', 'yuantool.network']  # 这个参数是导入目录下的所有__init__.py包
)
